@@ -201,8 +201,7 @@ class Connection():
         return stetament
 
     def __is_clause_table__(self, condition):
-        regex=re.compile('((([a-zA-Z]+\_?)+)\.)')
-        if not re.match(regex, condition):
+        if not '.' in condition or len(re.findall(r"\"\S+\.\S+\"|\'\S+\.\S+\'|\d+\.\d+?", condition)) > 0:
             return True
         else:
             if not f"{self._table}." in condition:
@@ -218,11 +217,10 @@ class Connection():
 
     def __format_select_query__(self):
         # SELECT BLOCK
-        _select = '*' if not self._select else ', '.join([c for c in self._select if self.__is_clause_table__(c)])
+        _select = '*' if not self._select else ', '.join([f"{self._table}.{c} AS '{c}'" for c in self._select if self.__is_clause_table__(c)])
 
         if _select == '*':
             _select = ", ".join([f"{self._table}.{field} AS '{field}'" for field in self._klass.__dict__ if not field.startswith("_") and not self._klass[field].__class__.__name__.startswith("Obj")])
-
         if not all([f'{self._table}.{pk}' in _select for pk in self._klass.__metadata__['pk']]):
             _select = _select + ", " + ", ".join([f"{self._table}.{field} AS '{field}'" for field in self._klass.__dict__ if not field.startswith("_") and field in self._klass.__metadata__['pk']])
 
